@@ -59,6 +59,9 @@ public:
    void
    slider(int value);
 
+   void
+   sliderUpdate();
+
    void
    pitchCallback(int value);
 
@@ -80,8 +83,10 @@ public:
    void
    menuCallback(int value);
 
+#if 0
    void
    emailCallback(int value);
+#endif
 
    void
    setDir();
@@ -181,6 +186,7 @@ QString           _file;
 bool              _debug;
 QMenu            *helpMenu;
 QAction          *aboutAct;
+int              _slider_value;
 
 };
 
