@@ -94,7 +94,7 @@ aflibMadFile::afopen(
 {
    // This function will open an existing MP3 file.
 
-   string cmd_str;
+   string cmd_str("madplay -v --time=00:00:00.001 --output=null:/dev/null \"");
    aflibConfig  input_cfg(*cfg);
    char  buf[10240];
    long info_size = 0;
@@ -104,9 +104,6 @@ aflibMadFile::afopen(
    long long    samples;
 
    // USING popen
-   cmd_str = "madplay";
-   cmd_str += " -v --time=00:00:00.001 --output=raw:";
-   cmd_str += "/dev/null \"";
    cmd_str += file;
    cmd_str += "\" 2>&1";
 
